http://localhost:8501/?action=scripts&name=run-mlperf-inference-app,4a5d5b13fd7e4ac8&gui=true&@implementation=nvidia-original&@device=cuda
http://localhost:8501/?action=scripts&name=run-mlperf-inference-app,4a5d5b13fd7e4ac8&gui=true&@implementation=nvidia-original&@device=cuda&@submitter=xyz&clean=false
http://localhost:8501/?action=scripts&name=run-mlperf-inference-app,4a5d5b13fd7e4ac8&gui=true&@implementation=nvidia-original&@device=cuda&@submitter=xyz&clean=false&~~submission-generation-style=full&~dashboard=false
